@@ -11,7 +11,7 @@ DATABASES = {
 
 AUTH_USER_MODEL = 'tests.CustomUser'
 
-LOGIN_CODE_TIMEOUT = 900
+NOPASSWORD_LOGIN_CODE_TIMEOUT = 900
 
 INSTALLED_APPS = [
     'django.contrib.auth',
